# Fuisce

Full README incoming...


## Installation

_Fuisce_ is registered on the [Python Package Index (PyPI)](https://pypi.org/project/fuisce) for easy installation.
To install the package, simply run

```
$ pip install fuisce
```

The package requires a recent version of Python (3.9+).


## License

This project is licensed under the GNU General Public License, Version 3.
It is fully open-source, and while you are more than welcome to fork, add, modify, etc. it is required that you keep any distributed changes and additions open-source.


## Changes

Changes between versions are tracked in the [changelog](CHANGELOG.md).
